#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Welcome to stacksearch.

Stacksearch is a simple tool aimed for people who never want to leave the terminal.
Stacksearch can also search other Stack Exchange websites, not just StackOverflow.
"""


__version__ = "1.3.10"

__author__ = "Bryan Hu"

__all__ = ["__main__", "Search"]

__credits__: str = ["KomodoKode"]
